Laser Fields
============

Objects for creating laser beam objects, along with some common components.

Overview
--------

.. currentmodule:: pylcp

.. autosummary::

    laserBeam
    infinitePlaneWaveBeam
    gaussianBeam
    clippedGaussianBeam
    laserBeams
    conventional3DMOTBeams


Details
-------

  .. autoclass:: pylcp.laserBeam
    :members:

  .. autoclass:: pylcp.infinitePlaneWaveBeam
    :members:

  .. autoclass:: pylcp.gaussianBeam
    :members:

  .. autoclass:: pylcp.clippedGaussianBeam
    :members:

  .. autoclass:: pylcp.laserBeams
    :members:

  .. autoclass:: pylcp.conventional3DMOTBeams
    :members:
